@@ -25,8 +25,8 @@ GeomPolygon <- proto(Geom, {
     data <- aesdefaults(data, .$default_aes(), list(...))
   
     with(data, grobTree(
-      rectGrob(gp = gpar(col = colour, fill = fill)),
-      linesGrob(gp = gpar(col = colour, lwd = size * .pt, lineend="butt"))
+      rectGrob(gp = gpar(col = colour, fill = fill, lty = linetype)),
+      linesGrob(gp = gpar(col = colour, lwd = size * .pt, lineend="butt", lty = linetype))
     ))
   }
 
