@@ -58,8 +58,8 @@ GeomRibbon <- proto(Geom, {
     (m <- m + geom_point())
     
     # The default summary isn't that useful
-    m + stat_summary(geom="ribbon", fun="range")
-    m + stat_summary(geom="ribbon", fun="median_hilow")
+    m + stat_summary(geom="ribbon", fun.ymin="min", fun.ymax="max")
+    m + stat_summary(geom="ribbon", fun.data="median_hilow")
     
     # Use qplot instead
     qplot(year, level, data=huron, geom=c("area", "line"))
