@@ -157,8 +157,9 @@ build_legend <- function(name, mapping, layers, default_mapping, theme) {
 }
 
 build_legend_data <- function(layer, mapping, default_mapping) {
-  all <- names(c(layer$mapping, default_mapping))
+  all <- names(c(layer$mapping, default_mapping, layer$stat$default_aes()))
   geom <- c(layer$geom$required_aes, names(layer$geom$default_aes()))
+  
   matched <- intersect(intersect(all, geom), names(mapping))
   matched <- setdiff(matched, names(layer$geom_params))
 
@@ -166,7 +167,7 @@ build_legend_data <- function(layer, mapping, default_mapping) {
     # This layer contributes to the legend
     if (is.na(layer$legend) || layer$legend) {
       # Default is to include it 
-      layer$use_defaults(mapping[matched])        
+      layer$use_defaults(mapping[matched])
     } else {
       NULL
     }
