@@ -4,14 +4,15 @@ StatSum <- proto(Stat, {
   default_geom <- function(.) GeomPoint
   icon <- function(.) textGrob(expression(Sigma), gp=gpar(cex=4))
   
-  calculate <- function(., data, scales, ...) {
+  calculate_groups <- function(., data, scales, ...) {
     if (is.null(data$weight)) data$weight <- 1
     
-    counts <- as.data.frame(xtabs(weight ~ x + y, data), responseName="sum")
-    counts[c("x", "y")] <- lapply(counts[c("x", "y")], 
-      function(x) as.numeric(as.character(x)))
-    counts$prop <- counts$sum / sum(counts$sum)
+    counts <- ddply(data, .(x, y, group), function(df) {
+      data.frame(n = sum(df$weight), uniquecols(df))
+    })
+    counts <- ddply(counts, .(group), transform, prop = n / sum(n))
     counts$group <- 1
+
     counts
   }
   
@@ -19,11 +20,11 @@ StatSum <- proto(Stat, {
   desc <- "Sum unique values.  Useful for overplotting on scatterplots"
   seealso <- list(
     "ggfluctuation" = "Fluctuation diagram, which is very similar"
+    # "round_any" = "for rounding continuous observations to desired level of accuracy"
   )
   desc_outputs <- list(
-    "sum" = "number of observations at position",
-    "prop" = "percent of points in that panel at that position",
-    "round_any" = "for rounding continuous observations to desired level of accuracy"
+    "n" = "number of observations at position",
+    "prop" = "percent of points in that panel at that position"
   )
   
   examples <- function(.) {
@@ -35,18 +36,21 @@ StatSum <- proto(Stat, {
     d + stat_sum(aes(group = 1)) + scale_area(to = c(3, 10))
     # by cut
     d + stat_sum(aes(group = cut))
+    d + stat_sum(aes(group = clarity, colour = cut))
     # by clarity
     d + stat_sum(aes(group = clarity))
+    d + stat_sum(aes(group = clarity, colour = clarity))
+    
+    # Instead of proportions, can also use sums
+    d + stat_sum(aes(size = ..n..))
 
     # Can also weight by another variable
     d + stat_sum(aes(group = 1, weight = price))
-    d + stat_sum(aes(group = 1, weight = price, size = ..sum..))
-    
+    d + stat_sum(aes(group = 1, weight = price, size = ..n..))
     
     # Or using qplot
     qplot(cut, clarity, data = diamonds)
-    qplot(cut, clarity, data = diamonds, stat = "sum", group = 1)
-    
+    qplot(cut, clarity, data = diamonds, stat = "sum", group = 1)    
   }
   
 })
