@@ -43,7 +43,7 @@ try_require <- function(package) {
   missing <- package[!available]
 
   if (length(missing) > 0) 
-    stop(paste(package, collapse=", "), " required for this functionality.  Please install and try again.", call. = FALSE)
+    stop(paste(package, collapse=", "), " package required for this functionality.  Please install and try again.", call. = FALSE)
 }
 
 # Return unique columns
