@@ -76,6 +76,7 @@ scale_x_asn <- ScaleAsn$build_accessor(list(variable = "\"x\""))
 scale_x_atanh <- ScaleAtanh$build_accessor(list(variable = "\"x\""))
 scale_x_continuous <- ScaleContinuous$build_accessor(list(variable = "\"x\""))
 scale_x_date <- ScaleDate$build_accessor(list(variable = "\"x\""))
+scale_x_datetime <- ScaleDatetime$build_accessor(list(variable = "\"x\""))
 scale_x_discrete <- ScaleDiscretePosition$build_accessor(list(variable = "\"x\""))
 scale_x_exp <- ScaleExp$build_accessor(list(variable = "\"x\""))
 scale_x_inverse <- ScaleInverse$build_accessor(list(variable = "\"x\""))
@@ -93,6 +94,7 @@ scale_y_asn <- ScaleAsn$build_accessor(list(variable = "\"y\""))
 scale_y_atanh <- ScaleAtanh$build_accessor(list(variable = "\"y\""))
 scale_y_continuous <- ScaleContinuous$build_accessor(list(variable = "\"y\""))
 scale_y_date <- ScaleDate$build_accessor(list(variable = "\"y\""))
+scale_y_datetime <- ScaleDatetime$build_accessor(list(variable = "\"y\""))
 scale_y_discrete <- ScaleDiscretePosition$build_accessor(list(variable = "\"y\""))
 scale_y_exp <- ScaleExp$build_accessor(list(variable = "\"y\""))
 scale_y_inverse <- ScaleInverse$build_accessor(list(variable = "\"y\""))
@@ -107,6 +109,7 @@ scale_y_probit <- ScaleProbit$build_accessor(list(variable = "\"y\""))
 scale_y_reverse <- ScaleReverse$build_accessor(list(variable = "\"y\""))
 scale_y_sqrt <- ScaleSqrt$build_accessor(list(variable = "\"y\""))
 scale_z_discrete <- ScaleDiscretePosition$build_accessor(list(variable = "\"z\""))
+stat_abline <- StatAbline$build_accessor()
 stat_bin <- StatBin$build_accessor()
 stat_bin2d <- StatBin2d$build_accessor()
 stat_binhex <- StatBinhex$build_accessor()
